@@ -57,6 +57,10 @@ def generate(env):
     if version:
         env['CCVERSION'] = version
 
+    env['CCDEPFLAGS'] = '-MMD -MF ${TARGET}.d'
+    env["NINJA_DEPFILE_PARSE_FORMAT"] = 'gcc'
+
+
 
 def exists(env):
     # is executable, and is a GNU compiler (or accepts '--version' at least)
@@ -74,14 +78,13 @@ def detect_version(env, cc):
     # GCC versions older than that, we should use --version and a
     # regular expression.
     # pipe = SCons.Action._subproc(env, SCons.Util.CLVar(cc) + ['-dumpversion'],
-    pipe=SCons.Action._subproc(env, SCons.Util.CLVar(cc) + ['--version'],
+    with SCons.Action._subproc(env, SCons.Util.CLVar(cc) + ['--version'],
                                  stdin='devnull',
                                  stderr='devnull',
-                                 stdout=subprocess.PIPE)
-    if pipe.wait() != 0:
-        return version
+                                 stdout=subprocess.PIPE) as pipe:
+        if pipe.wait() != 0:
+            return version
 
-    with pipe.stdout:
         # -dumpversion variant:
         # line = pipe.stdout.read().strip()
         # --version variant:
